// import '../style.css';

import React, { useMemo } from 'react';

import {
  ConnectionProvider,
  WalletProvider,
} from '@solana/wallet-adapter-react';

import { E2EWalletAdapter, E2EWalletAdapterConfig } from '../adapters/e2e';
import { DemonWalletAdapter } from '../adapters/index';
import {
  getNetworkUrls,
} from '../helpers';
import {
  WalletModalProvider,
  type WalletModalProviderProps,
} from './WalletModalProvider';

export interface WalletUIProviderProps extends WalletModalProviderProps {
  isMainnet: boolean,
  e2e?: boolean,
  e2eWalletAdapterConfig?: E2EWalletAdapterConfig
}

export const Provider = ({
  children,
  isMainnet,
  e2e,
  e2eWalletAdapterConfig,
  ...modalProviderProps
}: WalletUIProviderProps) => {
  const wallets = useMemo(() => {
    const supportedWallets = []
    if (e2e) {
      supportedWallets.push(new E2EWalletAdapter(e2eWalletAdapterConfig))
    } else {
      supportedWallets.push(new DemonWalletAdapter())
    }

    return supportedWallets
  }, [e2e, e2eWalletAdapterConfig])

  const urls = useMemo(() => getNetworkUrls(isMainnet), [])

  return (
    <ConnectionProvider
      endpoint={urls.rpc}
      config={{
        wsEndpoint: urls.wss,
        commitment: 'confirmed',
      }}
    >
      <WalletProvider
        wallets={wallets}
        autoConnect
      >
        <WalletModalProvider
          {...modalProviderProps}
        >
          {children}
        </WalletModalProvider>
      </WalletProvider>
    </ConnectionProvider>
  )
}
